@@ -5,7 +5,7 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-# 20230706 raf <raf@raf.org>
+# 20230709 raf <raf@raf.org>
 
 package Lingua::NameUtils;
 use 5.014;
@@ -13,7 +13,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 use Exporter;
 our @ISA = ('Exporter');
@@ -869,6 +869,7 @@ sub namecase_exception
 	}
 	else # Family-wide exception
 	{
+		%namecase_exceptions = map { kc($_) => $_ } @namecase_exceptions unless %namecase_exceptions;
 		$namecase_exceptions{$kcname} = $name;
 	}
 
@@ -1004,8 +1005,9 @@ sub namesplit
 			$ja_loaded = 1;
 		}
 
+		local $SIG{__WARN__} = sub {}; # Suppress warnings
 		($f, $g) = Lingua::JA::Name::Splitter::split_kanji_name($name);
-		return "$f, $g";
+		return join(', ', grep { length } $f, $g);
 	}
 
 	# Assume a single-word family name
@@ -1103,6 +1105,8 @@ sub normalize
 	%fnamecase_exceptions_full = map { $func->($_) => $func->($fnamecase_exceptions_full{$_}) } keys %fnamecase_exceptions_full;
 	$namecase_exceptions_re = $func->($namecase_exceptions_re) if defined $namecase_exceptions_re;
 	%namesplit_exceptions = map { $func->($_) => $func->($namesplit_exceptions{$_}) } keys %namesplit_exceptions;
+	@split_starter = map { $func->($_) } @split_starter;
+	$split_starter_re = $func->($split_starter_re) if defined $split_starter_re;
 	%split_starter = map { $func->($_) => 1 } keys %split_starter;
 	@irish_o = map { $func->($_) } @irish_o;
 	$irish_o_re = '(?:' . join('|', @irish_o) . ')';
@@ -1125,4 +1129,23 @@ sub normalize
 	@family_names_vietnamese = map { $func->($_) }  @family_names_vietnamese;
 }
 
+# Reset internal data (for test coverage purposes)
+
+sub _reset_data
+{
+	%namecase_exceptions = (); # This is the only one that matters (initialized in two places)
+	%namecase_exceptions_full = ();
+	%fnamecase_exceptions_full = ();
+	$need_case_update = 1;
+	$namecase_exceptions_re = undef;
+	%split_starter = ();
+	$split_starter_re = undef;
+	%family_names_ck = ();
+	$family_names_ck_re = undef;
+	%family_names_ck_roman = ();
+	$family_names_ck_roman_re = undef;
+	%family_names_v_roman = ();
+	$family_names_v_roman_re = undef;
+}
+
 1;
